MDbase :: auto-join + process multiple XLSX databases
-----------------------------------------------------

* MDbase is a Python package that...
	- Reads multiple XLSX files and joins them into one single database
	- Enables fast and easy data mining = correlations, comparisons...


Documentation, help and examples
--------------------------------

More detailed help, demo and source code including documentation are in
[GitHub](https://mirekslouf.github.io/mcreep).


Versions of MDbase
------------------

* Version 0.1 = complete, working, but without detailed documentation

